@@ -1,6 +1,6 @@
 package DBIx::Class::AuditLog;
 {
-  $DBIx::Class::AuditLog::VERSION = '0.2.4';
+  $DBIx::Class::AuditLog::VERSION = '0.2.5';
 }
 
 use base qw/DBIx::Class/;
@@ -129,11 +129,13 @@ sub _store_changes {
 
 
 sub _do_audit {
-    my $self = shift;
+    my $self   = shift;
     my $column = shift;
 
     my $info = $self->column_info($column);
-    return defined $info->{audit_log_column} && $info->{audit_log_column} == 0 ? 0 : 1;
+    return
+        defined $info->{audit_log_column}
+        && $info->{audit_log_column} == 0 ? 0 : 1;
 }
 
 # ABSTRACT: Simple activity audit logging for DBIx::Class
@@ -149,7 +151,7 @@ DBIx::Class::AuditLog - Simple activity audit logging for DBIx::Class
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 DBIx::Class OVERRIDDEN METHODS
 
